diff --git a/src/test/regress/input/tablespace.source b/src/test/regress/input/tablespace.source
index 2e676e9..9d47d62 100644
--- a/src/test/regress/input/tablespace.source
+++ b/src/test/regress/input/tablespace.source
@@ -75,6 +75,19 @@ ALTER TABLE testschema.test_default_tab ALTER id TYPE bigint;
 \d testschema.test_index2
 DROP TABLE testschema.test_default_tab;
 
+-- check that default_tablespace affects index additions in ALTER TABLE
+CREATE TABLE testschema.test_tab(id int) TABLESPACE regress_tblspace;
+INSERT INTO testschema.test_tab VALUES (1);
+-- test with default tablespace
+SET default_tablespace TO '';
+ALTER TABLE testschema.test_tab ADD CONSTRAINT test_tab_pkey PRIMARY KEY (id);
+SET default_tablespace TO regress_tblspace;
+ALTER TABLE testschema.test_tab ADD CONSTRAINT test_tab_unique UNIQUE (id);
+\d testschema.test_tab_pkey
+\d testschema.test_tab_unique
+SELECT * FROM testschema.test_tab;
+DROP TABLE testschema.test_tab;
+
 -- let's try moving a table from one place to another
 CREATE TABLE testschema.atable AS VALUES (1), (2);
 CREATE UNIQUE INDEX anindex ON testschema.atable(column1);
diff --git a/src/test/regress/output/tablespace.source b/src/test/regress/output/tablespace.source
index 6e0dfd1..ae2cf9a 100644
--- a/src/test/regress/output/tablespace.source
+++ b/src/test/regress/output/tablespace.source
@@ -166,6 +166,36 @@ btree, for table "testschema.test_default_tab"
 Tablespace: "regress_tblspace"
 
 DROP TABLE testschema.test_default_tab;
+-- check that default_tablespace affects index additions in ALTER TABLE
+CREATE TABLE testschema.test_tab(id int) TABLESPACE regress_tblspace;
+INSERT INTO testschema.test_tab VALUES (1);
+-- test with default tablespace
+SET default_tablespace TO '';
+ALTER TABLE testschema.test_tab ADD CONSTRAINT test_tab_pkey PRIMARY KEY (id);
+SET default_tablespace TO regress_tblspace;
+ALTER TABLE testschema.test_tab ADD CONSTRAINT test_tab_unique UNIQUE (id);
+\d testschema.test_tab_pkey
+Index "testschema.test_tab_pkey"
+ Column |  Type   | Definition 
+--------+---------+------------
+ id     | integer | id
+primary key, btree, for table "testschema.test_tab"
+
+\d testschema.test_tab_unique
+Index "testschema.test_tab_unique"
+ Column |  Type   | Definition 
+--------+---------+------------
+ id     | integer | id
+unique, btree, for table "testschema.test_tab"
+Tablespace: "regress_tblspace"
+
+SELECT * FROM testschema.test_tab;
+ id 
+----
+  1
+(1 row)
+
+DROP TABLE testschema.test_tab;
 -- let's try moving a table from one place to another
 CREATE TABLE testschema.atable AS VALUES (1), (2);
 CREATE UNIQUE INDEX anindex ON testschema.atable(column1);
